@@ -2,16 +2,30 @@
 # This is a .pm just to (try to) make some CPAN document converters
 #  convert it happily as part of the dist's documentation tree.
 package HTML::Element::traverse;
- # Time-stamp: "2001-01-20 12:28:57 MST"
+
+# ABSTRACT: discussion of HTML::Element's traverse method
+
+use warnings;
+use strict;
+
+our $VERSION = '5.00'; # VERSION from OurPkgVersion
+
 use HTML::Element ();
-$VERSION = $VERSION = $HTML::Element::VERSION;
 1;
 
+
 __END__
+=pod
 
 =head1 NAME
 
-HTML::Element traverse - discussion of HTML::Element's traverse method
+HTML::Element::traverse - discussion of HTML::Element's traverse method
+
+=head1 VERSION
+
+This document describes version 5.00 of
+HTML::Element::traverse, released June 12, 2012
+as part of L<HTML-Tree|HTML::Tree>.
 
 =head1 SYNOPSIS
 
@@ -84,7 +98,7 @@ following syntaxes:
 
 =item or $h->traverse(\&callback, $ignore_text)
 
-=item or $h->traverse([\&pre_callback,\&post_callback], $ignore_text)
+=item or $h->traverse( [\&pre_callback,\&post_callback] , $ignore_text)
 
 =back
 
@@ -119,7 +133,7 @@ arguments to the callback:
 Note that you can specify that the pre-order routine can
 be a different routine from the post-order one:
 
-    $h->traverse([\&pre_callback,\&post_callback], ...);
+    $h->traverse( [\&pre_callback,\&post_callback], ...);
 
 You can also specify that no post-order calls are to be made,
 by providing a false value as the post-order routine:
@@ -135,7 +149,7 @@ Note that these two syntaxes specify the same operation:
     $h->traverse([\&foo,\&foo], ...);
     $h->traverse( \&foo       , ...);
 
-The return values from calls to your pre- or post-order 
+The return values from calls to your pre- or post-order
 routines are significant, and are used to control recursion
 into the tree.
 
@@ -255,11 +269,11 @@ pre-order traversal, like so:
      my @to_do = ($tree); # start-node
      while(@to_do) {
        my $this = shift @to_do;
-       
+
        # "Visit" the node:
        $this->attr('id', $counter++)
         unless defined $this->attr('id');
-       
+
        unshift @to_do, grep ref $_, $this->content_list;
         # Put children on the stack -- they'll be visited next
      }
@@ -274,7 +288,7 @@ is insignificant.
 
 =head2 Pruning and Whatnot
 
-The C<traverse> method does have the fairly neat features of 
+The C<traverse> method does have the fairly neat features of
 the C<ABORT>, C<PRUNE_UP> and C<PRUNE_SOFTLY> signals.  None of these
 can be implemented I<totally> straightforwardly with recursive
 routines, but it is quite possible.  C<ABORT>-like behavior can be
@@ -318,12 +332,44 @@ or you can just do it with flags:
 
 L<HTML::Element>
 
-=head1 COPYRIGHT
-
-Copyright 2000 Sean M. Burke
-
 =head1 AUTHOR
 
-Sean M. Burke, E<lt>sburke@cpan.orgE<gt>
+Current maintainers:
+
+=over
+
+=item * Christopher J. Madsen S<C<< <perl AT cjmweb.net> >>>
+
+=item * Jeff Fearn S<C<< <jfearn AT cpan.org> >>>
+
+=back
+
+Original HTML-Tree author:
+
+=over
+
+=item * Gisle Aas
+
+=back
+
+Former maintainers:
+
+=over
+
+=item * Sean M. Burke
+
+=item * Andy Lester
+
+=item * Pete Krawczyk S<C<< <petek AT cpan.org> >>>
+
+=back
+
+You can follow or contribute to HTML-Tree's development at
+L<< http://github.com/madsen/HTML-Tree >>.
+
+=head1 COPYRIGHT
+
+Copyright 2000,2001 Sean M. Burke
 
 =cut
+
