@@ -1,41 +1,16 @@
 package HTML::Tree;
 
-=head1 NAME
-
-HTML::Tree - build and scan parse-trees of HTML
-
-=head1 VERSION
-
-4.1
-
-=cut
+# ABSTRACT: build and scan parse-trees of HTML
 
 # HTML::Tree is basically just a happy alias to HTML::TreeBuilder.
 
 use warnings;
 use strict;
 
+our $VERSION = '5.00'; # VERSION from OurPkgVersion
+
 use HTML::TreeBuilder ();
 
-use vars qw( $VERSION );
-$VERSION = '4.1';
-
-=head1 SYNOPSIS
-
-    use HTML::TreeBuilder;
-    my $tree = HTML::TreeBuilder->new();
-    $tree->parse_file($filename);
-
-        # Then do something with the tree, using HTML::Element
-        # methods -- for example:
-
-    $tree->dump
-
-        # Finally:
-
-    $tree->delete;
-
-=cut
 
 sub new {
     shift;
@@ -55,6 +30,44 @@ sub new_from_content {
     goto &HTML::TreeBuilder::new_from_content;
 }
 
+sub new_from_url {
+    shift;
+    unshift @_, 'HTML::TreeBuilder';
+    goto &HTML::TreeBuilder::new_from_url;
+}
+
+1;
+
+
+
+__END__
+=pod
+
+=head1 NAME
+
+HTML::Tree - build and scan parse-trees of HTML
+
+=head1 VERSION
+
+This document describes version 5.00 of
+HTML::Tree, released June 12, 2012
+as part of L<HTML-Tree|HTML::Tree>.
+
+=head1 SYNOPSIS
+
+    use HTML::TreeBuilder;
+    my $tree = HTML::TreeBuilder->new();
+    $tree->parse_file($filename);
+
+        # Then do something with the tree, using HTML::Element
+        # methods -- for example:
+
+    $tree->dump
+
+        # Finally:
+
+    $tree->delete;
+
 =head1 DESCRIPTION
 
 HTML-Tree is a suite of Perl modules for making parse trees out of
@@ -96,23 +109,27 @@ data structures should read just the last article.  Readers without
 that background should read the first, then the second, and then the
 third.
 
+=head1 METHODS
+
+All these methods simply redirect to the corresponding method in
+HTML::TreeBuilder.  It's more efficient to use HTML::TreeBuilder
+directly, and skip loading HTML::Tree at all.
+
 =head2 new
 
-Redirects to HTML::TreeBuilder::new
-
-=cut
+Redirects to L<HTML::TreeBuilder/new>.
 
 =head2 new_from_file
 
-Redirects to HTML::TreeBuilder::new_from_file
-
-=cut
+Redirects to L<HTML::TreeBuilder/new_from_file>.
 
 =head2 new_from_content
 
-Redirects to HTML::TreeBuilder::new_from_content
+Redirects to L<HTML::TreeBuilder/new_from_content>.
 
-=cut
+=head2 new_from_url
+
+Redirects to L<HTML::TreeBuilder/new_from_url>.
 
 =head1 SUPPORT
 
@@ -140,6 +157,13 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HTML-Tree>
 
 L<http://search.cpan.org/dist/HTML-Tree>
 
+=item * Stack Overflow
+
+L<http://stackoverflow.com/questions/tagged/html-tree>
+
+If you have a question about how to use HTML-Tree, Stack Overflow is
+the place to ask it.  Make sure you tag it both C<perl> and C<html-tree>.
+
 =back
 
 =head1 SEE ALSO
@@ -159,15 +183,10 @@ and HTML-Tree specifically.  There's more info at:
 
 =head1 SOURCE REPOSITORY
 
-HTML::Tree is maintained in Subversion hosted at perl.org.
+HTML-Tree is now maintained using Git.  The main public repository is
+L<< http://github.com/madsen/HTML-Tree >>.
 
-    http://svn.perl.org/modules/HTML-Tree
-
-The latest development work is always at:
-
-    http://svn.perl.org/modules/HTML-Tree/trunk
-
-Any patches sent should be diffed against this repository.
+The best way to send a patch is to make a pull request there.
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -182,16 +201,47 @@ Terrence Brannon, Gordon Lack, Chris Madsen and Ricardo Signes.
 
 =head1 AUTHOR
 
-Original HTML-Tree author Gisle Aas.  Handed off to Sean M. Burke.
-and Andy Lester.  Currently maintained by Pete Krawczyk
-C<< <petek@cpan.org> >>.
+Current maintainers:
 
-=head1 COPYRIGHT
+=over
 
-Copyright 1995-1998 Gisle Aas; 1999-2004 Sean M. Burke; 
-2005 Andy Lester; 2006 Pete Krawczyk.  (Except the articles
-contained in HTML::Tree::AboutObjects, HTML::Tree::AboutTrees, and
-HTML::Tree::Scanning, which are all copyright 2000 The Perl Journal.)
+=item * Christopher J. Madsen S<C<< <perl AT cjmweb.net> >>>
+
+=item * Jeff Fearn S<C<< <jfearn AT cpan.org> >>>
+
+=back
+
+Original HTML-Tree author:
+
+=over
+
+=item * Gisle Aas
+
+=back
+
+Former maintainers:
+
+=over
+
+=item * Sean M. Burke
+
+=item * Andy Lester
+
+=item * Pete Krawczyk S<C<< <petek AT cpan.org> >>>
+
+=back
+
+You can follow or contribute to HTML-Tree's development at
+L<< http://github.com/madsen/HTML-Tree >>.
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 1995-1998 Gisle Aas, 1999-2004 Sean M. Burke,
+2005 Andy Lester, 2006 Pete Krawczyk, 2010 Jeff Fearn,
+2012 Christopher J. Madsen.
+(Except the articles contained in HTML::Tree::AboutObjects,
+HTML::Tree::AboutTrees, and HTML::Tree::Scanning, which are all
+copyright 2000 The Perl Journal.)
 
 Except for those three TPJ articles, the whole HTML-Tree distribution,
 of which this file is a part, is free software; you can redistribute
@@ -206,4 +256,3 @@ warranty of merchantability or fitness for a particular purpose.
 
 =cut
 
-1;
